@@ -28,6 +28,9 @@ RocJpegDecoder::RocJpegDecoder(RocJpegBackend backend, int device_id) :
 RocJpegDecoder::~RocJpegDecoder() {
     if (hip_stream_) {
         hipError_t hip_status = hipStreamDestroy(hip_stream_);
+        if (hip_status != hipSuccess) {
+            ERR("ERROR: Failed to destroy the HIP stream!");
+        }
     }
 }
 
@@ -44,7 +47,6 @@ RocJpegDecoder::~RocJpegDecoder() {
  *         - ROCJPEG_STATUS_INVALID_PARAMETER if the requested device_id is not found.
  */
 RocJpegStatus RocJpegDecoder::InitHIP(int device_id) {
-    hipError_t hip_status = hipSuccess;
     CHECK_HIP(hipGetDeviceCount(&num_devices_));
     if (num_devices_ < 1) {
         ERR("ERROR: Failed to find any GPU!");
@@ -80,13 +82,15 @@ RocJpegStatus RocJpegDecoder::InitializeDecoder() {
     }
     if (backend_ == ROCJPEG_BACKEND_HARDWARE) {
         std::string gpu_uuid(hip_dev_prop_.uuid.bytes, sizeof(hip_dev_prop_.uuid.bytes));
-        rocjpeg_status = jpeg_vaapi_decoder_.InitializeDecoder(hip_dev_prop_.name, hip_dev_prop_.gcnArchName, device_id_, gpu_uuid);
+        rocjpeg_status = jpeg_vaapi_decoder_.InitializeDecoder(hip_dev_prop_.name, device_id_, gpu_uuid);
         if (rocjpeg_status != ROCJPEG_STATUS_SUCCESS) {
             ERR("ERROR: Failed to initialize the VA-API JPEG decoder!");
             return rocjpeg_status;
         }
     } else if (backend_ == ROCJPEG_BACKEND_HYBRID) {
         return ROCJPEG_STATUS_NOT_IMPLEMENTED;
+    } else {
+        return ROCJPEG_STATUS_INVALID_PARAMETER;
     }
     return rocjpeg_status;
 }
@@ -104,7 +108,6 @@ RocJpegStatus RocJpegDecoder::InitializeDecoder() {
  */
 RocJpegStatus RocJpegDecoder::Decode(RocJpegStreamHandle jpeg_stream_handle, const RocJpegDecodeParams *decode_params, RocJpegImage *destination) {
     std::lock_guard<std::mutex> lock(mutex_);
-    RocJpegStatus rocjpeg_status = ROCJPEG_STATUS_SUCCESS;
     if (jpeg_stream_handle == nullptr || decode_params == nullptr || destination == nullptr) {
         return ROCJPEG_STATUS_INVALID_PARAMETER;
     }
@@ -147,16 +150,16 @@ RocJpegStatus RocJpegDecoder::Decode(RocJpegStreamHandle jpeg_stream_handle, con
             CHECK_ROCJPEG(GetChromaHeight(hip_interop_dev_mem.surface_format, picture_height, chroma_height));
 
             // Copy Luma (first channel) for any surface format
-            CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_height, 0, destination, decode_params, is_roi_valid));
+            CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, picture_height, 0, destination, decode_params, is_roi_valid));
 
             if (hip_interop_dev_mem.surface_format == VA_FOURCC_NV12) {
                 // Copy the second channel (UV interleaved) for NV12
-                CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, chroma_height, 1, destination, decode_params, is_roi_valid));
+                CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, chroma_height, 1, destination, decode_params, is_roi_valid));
             } else if (hip_interop_dev_mem.surface_format == VA_FOURCC_444P ||
                        hip_interop_dev_mem.surface_format == VA_FOURCC_422V) {
                 // Copy the second and third channels for YUV444 and YUV440 (i.e., YUV422V)
-                CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, chroma_height, 1, destination, decode_params, is_roi_valid));
-                CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, chroma_height, 2, destination, decode_params, is_roi_valid));
+                CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, chroma_height, 1, destination, decode_params, is_roi_valid));
+                CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, chroma_height, 2, destination, decode_params, is_roi_valid));
             }
             break;
         case ROCJPEG_OUTPUT_YUV_PLANAR:
@@ -216,7 +219,7 @@ RocJpegStatus RocJpegDecoder::DecodeBatched(RocJpegStreamHandle *jpeg_streams, i
             jpeg_streams_params[j] = std::move(*jpeg_stream_params);
         }
 
-        CHECK_ROCJPEG(jpeg_vaapi_decoder_.SubmitDecodeBatched(jpeg_streams_params.data() + i, current_batch_size, decode_params, current_surface_ids.data() + i));
+        CHECK_ROCJPEG(jpeg_vaapi_decoder_.SubmitDecodeBatched(jpeg_streams_params.data() + i, current_batch_size, &decode_params[i], current_surface_ids.data() + i));
 
         for (int k = 0; k < current_batch_size; k++) {
             HipInteropDeviceMem hip_interop_dev_mem = {};
@@ -231,8 +234,8 @@ RocJpegStatus RocJpegDecoder::DecodeBatched(RocJpegStreamHandle *jpeg_streams, i
             bool is_roi_valid = false;
             uint32_t roi_width;
             uint32_t roi_height;
-            roi_width = decode_params->crop_rectangle.right - decode_params->crop_rectangle.left;
-            roi_height = decode_params->crop_rectangle.bottom - decode_params->crop_rectangle.top;
+            roi_width = decode_params[k + i].crop_rectangle.right - decode_params[k + i].crop_rectangle.left;
+            roi_height = decode_params[k + i].crop_rectangle.bottom - decode_params[k + i].crop_rectangle.top;
     
             if (roi_width > 0 && roi_height > 0 && roi_width <= jpeg_stream_params->picture_parameter_buffer.picture_width && roi_height <= jpeg_stream_params->picture_parameter_buffer.picture_height) {
                 is_roi_valid = true;
@@ -247,48 +250,50 @@ RocJpegStatus RocJpegDecoder::DecodeBatched(RocJpegStreamHandle *jpeg_streams, i
                 is_roi_valid = false;
             }
 
-            switch (decode_params->output_format) {
+            switch (decode_params[k + i].output_format) {
                 case ROCJPEG_OUTPUT_NATIVE:
                     // Copy the native decoded output buffers from interop memory directly to the destination buffers
                     CHECK_ROCJPEG(GetChromaHeight(hip_interop_dev_mem.surface_format, picture_height, chroma_height));
                     // Copy Luma (first channel) for any surface format
-                    CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_height, 0, &destinations[k + i], decode_params, is_roi_valid));
+                    CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, picture_height, 0, &destinations[k + i], &decode_params[k + i], is_roi_valid));
                     if (hip_interop_dev_mem.surface_format == VA_FOURCC_NV12) {
                         // Copy the second channel (UV interleaved) for NV12
-                        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, chroma_height, 1, &destinations[k + i], decode_params, is_roi_valid));
+                        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, chroma_height, 1, &destinations[k + i], &decode_params[k + i], is_roi_valid));
                     } else if (hip_interop_dev_mem.surface_format == VA_FOURCC_444P ||
                             hip_interop_dev_mem.surface_format == VA_FOURCC_422V) {
                         // Copy the second and third channels for YUV444 and YUV440 (i.e., YUV422V)
-                        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, chroma_height, 1, &destinations[k + i], decode_params, is_roi_valid));
-                        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, chroma_height, 2, &destinations[k + i], decode_params, is_roi_valid));
+                        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, chroma_height, 1, &destinations[k + i], &decode_params[k + i], is_roi_valid));
+                        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, chroma_height, 2, &destinations[k + i], &decode_params[k + i], is_roi_valid));
                     }
                     break;
                 case ROCJPEG_OUTPUT_YUV_PLANAR:
                     CHECK_ROCJPEG(GetChromaHeight(hip_interop_dev_mem.surface_format, picture_height, chroma_height));
                     CHECK_ROCJPEG(GetPlanarYUVOutputFormat(hip_interop_dev_mem, picture_width,
-                                                        picture_height, chroma_height, &destinations[k + i], decode_params, is_roi_valid));
+                                                        picture_height, chroma_height, &destinations[k + i], &decode_params[k + i], is_roi_valid));
                     break;
                 case ROCJPEG_OUTPUT_Y:
                     CHECK_ROCJPEG(GetYOutputFormat(hip_interop_dev_mem, picture_width,
-                                                picture_height, &destinations[k + i], decode_params, is_roi_valid));
+                                                picture_height, &destinations[k + i], &decode_params[k + i], is_roi_valid));
                     break;
                 case ROCJPEG_OUTPUT_RGB:
                     CHECK_ROCJPEG(ColorConvertToRGB(hip_interop_dev_mem, picture_width,
-                                                            picture_height, &destinations[k + i], decode_params, is_roi_valid));
+                                                            picture_height, &destinations[k + i], &decode_params[k + i], is_roi_valid));
                     break;
                 case ROCJPEG_OUTPUT_RGB_PLANAR:
                     CHECK_ROCJPEG(ColorConvertToRGBPlanar(hip_interop_dev_mem, picture_width,
-                                                            picture_height, &destinations[k + i], decode_params, is_roi_valid));
+                                                            picture_height, &destinations[k + i], &decode_params[k + i], is_roi_valid));
                     break;
                 default:
                     break;
             }
+        }
+        CHECK_HIP(hipStreamSynchronize(hip_stream_));
+        for (int k = 0; k < current_batch_size; k++) {
+            VASurfaceID current_surface_id = *(current_surface_ids.data() + k + i);
             CHECK_ROCJPEG(jpeg_vaapi_decoder_.SetSurfaceAsIdle(current_surface_id));
         }
-
     }
 
-    CHECK_HIP(hipStreamSynchronize(hip_stream_));
     return ROCJPEG_STATUS_SUCCESS;
 }
 /**
@@ -365,12 +370,13 @@ RocJpegStatus RocJpegDecoder::GetImageInfo(RocJpegStreamHandle jpeg_stream_handl
  * The `channel_height` parameter specifies the height of the channel.
  *
  * @param hip_interop_dev_mem The `HipInteropDeviceMem` object containing the source channel data.
+ * @param channel_width The width of the channel to be copied.
  * @param channel_height The height of the channel to be copied.
  * @param channel_index The index of the channel to be copied.
  * @param destination The `RocJpegImage` object representing the destination image.
  * @return The status of the operation. Returns `ROCJPEG_STATUS_SUCCESS` if the channel was copied successfully.
  */
-RocJpegStatus RocJpegDecoder::CopyChannel(HipInteropDeviceMem& hip_interop_dev_mem, uint16_t channel_height, uint8_t channel_index, RocJpegImage *destination, const RocJpegDecodeParams *decode_params, bool is_roi_valid) {
+RocJpegStatus RocJpegDecoder::CopyChannel(HipInteropDeviceMem& hip_interop_dev_mem, uint16_t channel_width, uint16_t channel_height, uint8_t channel_index, RocJpegImage *destination, const RocJpegDecodeParams *decode_params, bool is_roi_valid) {
     if (hip_interop_dev_mem.pitch[channel_index] != 0 && destination->pitch[channel_index] != 0 && destination->channel[channel_index] != nullptr) {
         uint32_t roi_offset = 0;
         if (is_roi_valid) {
@@ -388,12 +394,77 @@ RocJpegStatus RocJpegDecoder::CopyChannel(HipInteropDeviceMem& hip_interop_dev_m
             }
             roi_offset = top * hip_interop_dev_mem.pitch[channel_index] + left;
         }
+
+        uint32_t channel_widths[ROCJPEG_MAX_COMPONENT] = {};
+        uint32_t roi_width = decode_params->crop_rectangle.right - decode_params->crop_rectangle.left;
+        bool is_roi_width_valid = roi_width > 0 && roi_width <= channel_width;
+        switch (decode_params->output_format) {
+            case ROCJPEG_OUTPUT_NATIVE:
+                switch (hip_interop_dev_mem.surface_format) {
+                    case VA_FOURCC_444P:
+                        channel_widths[2] = channel_widths[1] = channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                        break;
+                    case VA_FOURCC_422V:
+                        channel_widths[2] = channel_widths[1] = channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                        break;
+                    case VA_FOURCC_YUY2:
+                        channel_widths[0] = (is_roi_width_valid ? roi_width : channel_width) * 2;
+                        break;
+                    case VA_FOURCC_NV12:
+                        channel_widths[1] = channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                        break;
+                    case VA_FOURCC_Y800:
+                        channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                        break;
+                    default:
+                        ERR("Unknown output format!");
+                        return ROCJPEG_STATUS_INVALID_PARAMETER;
+                    }
+                break;
+            case ROCJPEG_OUTPUT_YUV_PLANAR:
+                switch (hip_interop_dev_mem.surface_format) {
+                    case VA_FOURCC_444P:
+                        channel_widths[2] = channel_widths[1] = channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                        break;
+                    case VA_FOURCC_422V:
+                        channel_widths[2] = channel_widths[1] = channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                        break;
+                    case VA_FOURCC_YUY2:
+                        channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                        channel_widths[2] = channel_widths[1] = channel_widths[0] >> 1;
+                        break;
+                    case VA_FOURCC_NV12:
+                        channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                        channel_widths[2] = channel_widths[1] = channel_widths[0] >> 1;
+                        break;
+                    case VA_FOURCC_Y800:
+                        channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                        break;
+                    default:
+                        ERR("Unknown output format!");
+                        return ROCJPEG_STATUS_INVALID_PARAMETER;
+                    }
+                break;
+            case ROCJPEG_OUTPUT_Y:
+                channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                break;
+            case ROCJPEG_OUTPUT_RGB:
+                channel_widths[0] = (is_roi_width_valid ? roi_width : channel_width) * 3;
+                break;
+            case ROCJPEG_OUTPUT_RGB_PLANAR:
+                channel_widths[2] = channel_widths[1] = channel_widths[0] = is_roi_width_valid ? roi_width : channel_width;
+                break;
+            default:
+                ERR("Unknown output format!");
+                return ROCJPEG_STATUS_INVALID_PARAMETER;
+        }
+
         if (destination->pitch[channel_index] == hip_interop_dev_mem.pitch[channel_index]) {
             uint32_t channel_size = destination->pitch[channel_index] * channel_height;
             CHECK_HIP(hipMemcpyDtoDAsync(destination->channel[channel_index], hip_interop_dev_mem.hip_mapped_device_mem + hip_interop_dev_mem.offset[channel_index] + roi_offset, channel_size, hip_stream_));
         } else {
             CHECK_HIP(hipMemcpy2DAsync(destination->channel[channel_index], destination->pitch[channel_index], hip_interop_dev_mem.hip_mapped_device_mem + hip_interop_dev_mem.offset[channel_index] + roi_offset, hip_interop_dev_mem.pitch[channel_index],
-            destination->pitch[channel_index], channel_height, hipMemcpyDeviceToDevice, hip_stream_));
+            channel_widths[channel_index], channel_height, hipMemcpyDeviceToDevice, hip_stream_));
         }
     }
     return ROCJPEG_STATUS_SUCCESS;
@@ -547,7 +618,7 @@ RocJpegStatus RocJpegDecoder::ColorConvertToRGBPlanar(HipInteropDeviceMem& hip_i
         case VA_FOURCC_RGBP:
             // Copy red, green, and blue channels from the interop memory into the destination
             for (uint8_t channel_index = 0; channel_index < 3; channel_index++) {
-                CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_height, channel_index, destination, decode_params, is_roi_valid));
+                CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, picture_height, channel_index, destination, decode_params, is_roi_valid));
             }
            break;
         default:
@@ -591,15 +662,15 @@ RocJpegStatus RocJpegDecoder::GetPlanarYUVOutputFormat(HipInteropDeviceMem& hip_
                                                   destination->pitch[0], destination->pitch[1], hip_interop_dev_mem.hip_mapped_device_mem + roi_offset, hip_interop_dev_mem.pitch[0]);
     } else {
         // Copy Luma
-        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_height, 0, destination, decode_params, is_roi_valid));
+        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, picture_height, 0, destination, decode_params, is_roi_valid));
         if (hip_interop_dev_mem.surface_format == VA_FOURCC_NV12) {
             // Extract the interleaved UV channels and copy them into the second and third channels of the destination.
             ConvertInterleavedUVToPlanarUV(hip_stream_, picture_width >> 1, picture_height >> 1, destination->channel[1], destination->channel[2],
                 destination->pitch[1], hip_interop_dev_mem.hip_mapped_device_mem + hip_interop_dev_mem.offset[1] + roi_offset, hip_interop_dev_mem.pitch[1]);
         } else if (hip_interop_dev_mem.surface_format == VA_FOURCC_444P ||
                    hip_interop_dev_mem.surface_format == VA_FOURCC_422V) {
-            CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, chroma_height, 1, destination, decode_params, is_roi_valid));
-            CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, chroma_height, 2, destination, decode_params, is_roi_valid));
+            CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, chroma_height, 1, destination, decode_params, is_roi_valid));
+            CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, chroma_height, 2, destination, decode_params, is_roi_valid));
         }
     }
     return ROCJPEG_STATUS_SUCCESS;
@@ -631,7 +702,7 @@ RocJpegStatus RocJpegDecoder::GetYOutputFormat(HipInteropDeviceMem& hip_interop_
                               hip_interop_dev_mem.hip_mapped_device_mem + roi_offset, hip_interop_dev_mem.pitch[0]);
     } else {
         // Copy Luma
-        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_height, 0, destination, decode_params, is_roi_valid));
+        CHECK_ROCJPEG(CopyChannel(hip_interop_dev_mem, picture_width, picture_height, 0, destination, decode_params, is_roi_valid));
     }
     return ROCJPEG_STATUS_SUCCESS;
 }
\ No newline at end of file
